@@ -143,7 +143,7 @@ static struct _getopt_data getopt_data;
    whose names are inconsistent.  */
 
 #ifndef getenv
-extern char *getenv ();
+extern char *getenv ( void );
 #endif
 
 #endif /* not __GNU_LIBRARY__ */
